@@ -24,10 +24,6 @@
    #include <future>
 #endif
 
-#if defined(BOTAN_HAS_ECC_KEY)
-   #include <botan/ecc_key.h>
-#endif
-
 namespace Botan {
 
 /*
@@ -409,7 +405,7 @@ CertificatePathStatusCodes PKIX::check_crl(const std::vector<X509_Certificate>&
          }
 
          for(const auto& extension : crls[i]->extensions().extensions()) {
-            // XXX this is wrong - the OID might be defined but the extention not full parsed
+            // XXX this is wrong - the OID might be defined but the extension not full parsed
             // for example see #1652
 
             // is the extension critical and unknown?
@@ -732,7 +728,7 @@ Certificate_Status_Code PKIX::build_all_certificate_paths(std::vector<std::vecto
 
    while(!stack.empty()) {
       std::optional<X509_Certificate> last = stack.back().first;
-      // found a deletion marker that guides the DFS, backtracing
+      // found a deletion marker that guides the DFS, backtracking
       if(last == std::nullopt) {
          stack.pop_back();
          std::string fprint = path_so_far.back().fingerprint("SHA-256");
@@ -791,7 +787,7 @@ Certificate_Status_Code PKIX::build_all_certificate_paths(std::vector<std::vecto
          path_so_far.push_back(*last);
          certs_seen.emplace(fprint);
 
-         // push a deletion marker on the stack for backtracing later
+         // push a deletion marker on the stack for backtracking later
          stack.push_back({std::optional<X509_Certificate>(), false});
 
          for(const auto& trusted_cert : trusted_issuers) {
